@@ -7,7 +7,7 @@ import json
 import re
 import threading
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Optional, Union
 
 from pyproj._crs import (
     _CRS,
@@ -89,7 +89,7 @@ def _prepare_from_proj_string(in_crs_string: str) -> str:
     # make sure the projection starts with +proj or +init
     starting_params = ("+init", "+proj", "init", "proj")
     if not in_crs_string.startswith(starting_params):
-        kvpairs: List[str] = []
+        kvpairs: list[str] = []
         first_item_inserted = False
         for kvpair in in_crs_string.split():
             if not first_item_inserted and (kvpair.startswith(starting_params)):
@@ -643,7 +643,7 @@ class CRS:
 
         """
         # pylint: disable=too-many-branches,too-many-return-statements
-        cf_dict: Dict[str, Any] = {"crs_wkt": self.to_wkt(wkt_version)}
+        cf_dict: dict[str, Any] = {"crs_wkt": self.to_wkt(wkt_version)}
 
         # handle bound CRS
         if (
@@ -652,7 +652,7 @@ class CRS:
             and self.coordinate_operation.towgs84
             and self.source_crs
         ):
-            sub_cf: Dict[str, Any] = self.source_crs.to_cf(
+            sub_cf: dict[str, Any] = self.source_crs.to_cf(
                 wkt_version=wkt_version,
                 errcheck=errcheck,
             )
@@ -693,6 +693,8 @@ class CRS:
         # handle geographic CRS
         if self.geodetic_crs:
             cf_dict["geographic_crs_name"] = self.geodetic_crs.name
+            if self.geodetic_crs.datum:
+                cf_dict["horizontal_datum_name"] = self.geodetic_crs.datum.name
 
         if self.is_geographic:
             if self.coordinate_operation:
@@ -711,15 +713,11 @@ class CRS:
                         self.coordinate_operation.method_name.lower()
                     ](self.coordinate_operation)
                 )
-                if self.datum:
-                    cf_dict["horizontal_datum_name"] = self.datum.name
             else:
                 cf_dict["grid_mapping_name"] = "latitude_longitude"
             return cf_dict
 
         # handle projected CRS
-        if self.is_projected and self.datum:
-            cf_dict["horizontal_datum_name"] = self.datum.name
         coordinate_operation = None
         if not self.is_bound and self.is_projected:
             coordinate_operation = self.coordinate_operation
@@ -875,7 +873,7 @@ class CRS:
             name="undefined", components=[bound_crs or projected_crs, vertical_crs]
         )
 
-    def cs_to_cf(self) -> List[dict]:
+    def cs_to_cf(self) -> list[dict]:
         """
         .. versionadded:: 3.0.0
 
@@ -886,7 +884,7 @@ class CRS:
 
         Returns
         -------
-        List[dict]:
+        list[dict]:
             CF-1.8 version of the coordinate systems.
         """
         cf_axis_list = []
@@ -1035,13 +1033,13 @@ class CRS:
         )
 
     @property
-    def sub_crs_list(self) -> List["CRS"]:
+    def sub_crs_list(self) -> list["CRS"]:
         """
         If the CRS is a compound CRS, it will return a list of sub CRS objects.
 
         Returns
         -------
-        List[CRS]
+        list[CRS]
         """
         return [self.__class__(sub_crs) for sub_crs in self._crs.sub_crs_list]
 
@@ -1091,7 +1089,7 @@ class CRS:
         return self._crs.type_name
 
     @property
-    def axis_info(self) -> List[Axis]:
+    def axis_info(self) -> list[Axis]:
         """
         Retrieves all relevant axis information in the CRS.
         If it is a Bound CRS, it gets the axis list from the Source CRS.
@@ -1099,7 +1097,7 @@ class CRS:
 
         Returns
         -------
-        List[Axis]:
+        list[Axis]:
             The list of axis information.
         """
         return self._crs.axis_info
@@ -1199,6 +1197,7 @@ class CRS:
         self,
         version: Union[WktVersion, str] = WktVersion.WKT2_2019,
         pretty: bool = False,
+        output_axis_rule: Optional[bool] = None,
     ) -> str:
         """
         Convert the projection to a WKT string.
@@ -1211,6 +1210,7 @@ class CRS:
           - WKT1_GDAL
           - WKT1_ESRI
 
+        .. versionadded:: 3.6.0 output_axis_rule
 
         Parameters
         ----------
@@ -1219,19 +1219,21 @@ class CRS:
             Default is :attr:`pyproj.enums.WktVersion.WKT2_2019`.
         pretty: bool, default=False
             If True, it will set the output to be a multiline string.
+        output_axis_rule: bool, optional, default=None
+            If True, it will set the axis rule on any case. If false, never.
+            None for AUTO, that depends on the CRS and version.
 
         Returns
         -------
         str
         """
-        wkt = self._crs.to_wkt(version=version, pretty=pretty)
+        wkt = self._crs.to_wkt(
+            version=version, pretty=pretty, output_axis_rule=output_axis_rule
+        )
         if wkt is None:
-            warnings.warn(
+            raise CRSError(
                 f"CRS cannot be converted to a WKT string of a '{version}' version. "
-                "Select a different version of a WKT string or edit your CRS. Future"
-                "versions of pyproj will raise a CRSError in this case.",
-                FutureWarning,
-                stacklevel=2,
+                "Select a different version of a WKT string or edit your CRS."
             )
         return wkt
 
@@ -1254,12 +1256,7 @@ class CRS:
         """
         proj_json = self._crs.to_json(pretty=pretty, indentation=indentation)
         if proj_json is None:
-            warnings.warn(
-                "CRS cannot be converted to a PROJ JSON string. "
-                "Future versions of pyproj will raise a CRSError in this case.",
-                FutureWarning,
-                stacklevel=2,
-            )
+            raise CRSError("CRS cannot be converted to a PROJ JSON string.")
         return proj_json
 
     def to_json_dict(self) -> dict:
@@ -1295,12 +1292,7 @@ class CRS:
         """
         proj = self._crs.to_proj4(version=version)
         if proj is None:
-            warnings.warn(
-                "CRS cannot be converted to a PROJ string. "
-                "Future versions of pyproj will raise a CRSError in this case.",
-                FutureWarning,
-                stacklevel=2,
-            )
+            raise CRSError("CRS cannot be converted to a PROJ string.")
         return proj
 
     def to_epsg(self, min_confidence: int = 70) -> Optional[int]:
@@ -1384,7 +1376,7 @@ class CRS:
 
     def list_authority(
         self, auth_name: Optional[str] = None, min_confidence: int = 70
-    ) -> List[AuthorityMatchInfo]:
+    ) -> list[AuthorityMatchInfo]:
         """
         .. versionadded:: 3.2.0
 
@@ -1419,7 +1411,7 @@ class CRS:
 
         Returns
         -------
-        List[AuthorityMatchInfo]:
+        list[AuthorityMatchInfo]:
             List of authority matches for the CRS.
         """
         return self._crs.list_authority(
@@ -1448,6 +1440,23 @@ class CRS:
         """
         return self.__class__(self._crs.to_3d(name=name))
 
+    def to_2d(self, name: Optional[str] = None) -> "CRS":
+        """
+        .. versionadded:: 3.6.0
+
+        Convert the current CRS to the 2D version if it makes sense.
+
+        Parameters
+        ----------
+        name: str, optional
+            CRS name. Defaults to use the name of the original CRS.
+
+        Returns
+        -------
+        CRS
+        """
+        return self.__class__(self._crs.to_2d(name=name))
+
     @property
     def is_geographic(self) -> bool:
         """
@@ -1557,10 +1566,10 @@ class CRS:
     def __eq__(self, other: Any) -> bool:
         return self.equals(other)
 
-    def __getstate__(self) -> Dict[str, str]:
+    def __getstate__(self) -> dict[str, str]:
         return {"srs": self.srs}
 
-    def __setstate__(self, state: Dict[str, Any]):
+    def __setstate__(self, state: dict[str, Any]):
         self.__dict__.update(state)
         self._local = CRSLocal()
 
@@ -1572,7 +1581,7 @@ class CRS:
 
     def __repr__(self) -> str:
         # get axis information
-        axis_info_list: List[str] = []
+        axis_info_list: list[str] = []
         for axis in self.axis_info:
             axis_info_list.extend(["- ", str(axis), "\n"])
         axis_info_str = "".join(axis_info_list)
@@ -1639,7 +1648,7 @@ class CustomConstructorCRS(CRS):
     """
 
     @property
-    def _expected_types(self) -> Tuple[str, ...]:
+    def _expected_types(self) -> tuple[str, ...]:
         """
         These are the type names of the CRS class
         that are expected when using the from_* methods.
@@ -1726,13 +1735,13 @@ class CustomConstructorCRS(CRS):
         return None if self._crs.target_crs is None else CRS(self._crs.target_crs)
 
     @property
-    def sub_crs_list(self) -> List["CRS"]:
+    def sub_crs_list(self) -> list["CRS"]:
         """
         If the CRS is a compound CRS, it will return a list of sub CRS objects.
 
         Returns
         -------
-        List[CRS]
+        list[CRS]
         """
         return [CRS(sub_crs) for sub_crs in self._crs.sub_crs_list]
 
@@ -1771,7 +1780,7 @@ class GeographicCRS(CustomConstructorCRS):
     def __init__(
         self,
         name: str = "undefined",
-        datum: Any = "urn:ogc:def:datum:EPSG::6326",
+        datum: Any = "urn:ogc:def:ensemble:EPSG::6326",
         ellipsoidal_cs: Optional[Any] = None,
     ) -> None:
         """
@@ -1779,7 +1788,7 @@ class GeographicCRS(CustomConstructorCRS):
         ----------
         name: str, default="undefined"
             Name of the CRS.
-        datum: Any, default="urn:ogc:def:datum:EPSG::6326"
+        datum: Any, default="urn:ogc:def:ensemble:EPSG::6326"
             Anything accepted by :meth:`pyproj.crs.Datum.from_user_input` or
             a :class:`pyproj.crs.datum.CustomDatum`.
         ellipsoidal_cs: Any, optional
@@ -1787,15 +1796,19 @@ class GeographicCRS(CustomConstructorCRS):
             Anything accepted by :meth:`pyproj.crs.CoordinateSystem.from_user_input`
             or an Ellipsoidal Coordinate System created from :ref:`coordinate_system`.
         """
+        datum = Datum.from_user_input(datum).to_json_dict()
         geographic_crs_json = {
             "$schema": "https://proj.org/schemas/v0.2/projjson.schema.json",
             "type": "GeographicCRS",
             "name": name,
-            "datum": Datum.from_user_input(datum).to_json_dict(),
             "coordinate_system": CoordinateSystem.from_user_input(
                 ellipsoidal_cs or Ellipsoidal2DCS()
             ).to_json_dict(),
         }
+        if datum["type"] == "DatumEnsemble":
+            geographic_crs_json["datum_ensemble"] = datum
+        else:
+            geographic_crs_json["datum"] = datum
         super().__init__(geographic_crs_json)
 
 
@@ -2011,13 +2024,13 @@ class CompoundCRS(CustomConstructorCRS):
 
     _expected_types = ("Compound CRS",)
 
-    def __init__(self, name: str, components: List[Any]) -> None:
+    def __init__(self, name: str, components: list[Any]) -> None:
         """
         Parameters
         ----------
         name: str
             The name of the Compound CRS.
-        components: List[Any], optional
+        components: list[Any], optional
             List of CRS to create a Compound Coordinate System.
             List of anything accepted by :meth:`pyproj.crs.CRS.from_user_input`
         """
