@@ -24,12 +24,13 @@ from test.conftest import (
     PROJ_GTE_91,
     PROJ_GTE_901,
     PROJ_GTE_911,
+    PROJ_GTE_921,
     assert_can_pickle,
     grids_available,
 )
 
 
-class CustomCRS(object):
+class CustomCRS:
     def to_wkt(self):
         return CRS.from_epsg(4326).to_wkt()
 
@@ -231,6 +232,40 @@ def test_to_wkt_pretty():
     assert "\n" not in crs.to_wkt()
 
 
+@pytest.mark.parametrize(
+    "version, expected",
+    [
+        ("WKT1_GDAL", False),
+        ("WKT1_ESRI", False),
+        ("WKT2_2019", True),
+    ],
+)
+def test_to_wkt_with_axis_rule_4326(version, expected):
+    crs = CRS.from_epsg(4326)
+    axis = "AXIS"
+    assert (axis in crs.to_wkt(version)) == expected
+    assert (axis in crs.to_wkt(version, output_axis_rule=None)) == expected
+    assert axis in crs.to_wkt(version, output_axis_rule=True)
+    assert axis not in crs.to_wkt(version, output_axis_rule=False)
+
+
+@pytest.mark.parametrize(
+    "version, expected",
+    [
+        ("WKT1_GDAL", True),
+        ("WKT1_ESRI", False),
+        ("WKT2_2019", True),
+    ],
+)
+def test_to_wkt_with_axis_rule_32630(version, expected):
+    crs = CRS.from_epsg(32630)
+    axis = "AXIS"
+    assert (axis in crs.to_wkt(version)) == expected
+    assert (axis in crs.to_wkt(version, output_axis_rule=None)) == expected
+    assert axis in crs.to_wkt(version, output_axis_rule=True)
+    assert axis not in crs.to_wkt(version, output_axis_rule=False)
+
+
 def test_repr():
     with pytest.warns(FutureWarning):
         assert repr(CRS({"init": "EPSG:4326"})) == (
@@ -373,6 +408,8 @@ def test_datum_unknown():
         "+towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
     )
     datum_name = "Unknown based on WGS84 ellipsoid"
+    if PROJ_GTE_921:
+        datum_name = "Unknown based on WGS 84 ellipsoid"
     if PROJ_GTE_901:
         datum_name = f"{datum_name} using towgs84=0,0,0,0,0,0,0"
     assert crs.datum.name == datum_name
@@ -1608,6 +1645,36 @@ def test_to_3d__name():
     assert crs_3d.name == "TEST"
 
 
+@pytest.mark.parametrize(
+    "crs_input",
+    [
+        CRS("EPSG:4979"),  # native 3D
+        CRS("EPSG:2056").to_3d(),  # a 2D CRS converted to 3D
+        CRS("EPSG:4326+5773"),  # a 3D CRS based on a compound
+    ],
+)
+def test_to_2d(crs_input):
+    assert len(crs_input.axis_info) == 3
+    horizon_axis_crs_3d = crs_input.axis_info[:-1]
+    crs_2d = crs_input.to_2d()
+    horizon_axis_crs_2d = crs_input.axis_info
+    assert len(crs_2d.axis_info) == 2
+    assert horizon_axis_crs_2d[0] == horizon_axis_crs_3d[0]
+    assert horizon_axis_crs_2d[1] == horizon_axis_crs_3d[1]
+    assert crs_2d.to_2d() == crs_2d
+    # For CompoundCRS, the 3D name is initialized different from 2D
+    if crs_input.name == "WGS 84 + EGM96 height":
+        assert crs_2d.name == "WGS 84"
+    # Otherwise, no change
+    else:
+        assert crs_2d.name == crs_input.name
+
+
+def test_to_2d__name():
+    crs_2d = CRS("EPSG:2056").to_3d().to_2d(name="TEST")
+    assert crs_2d.name == "TEST"
+
+
 def test_crs__pickle(tmp_path):
     assert_can_pickle(CRS("epsg:4326"), tmp_path)
 
