@@ -221,6 +221,7 @@ def test_cf_from_latlon():
         "grid_mapping_name": "latitude_longitude",
         "geographic_crs_name": "undefined",
         "reference_ellipsoid_name": "undefined",
+        "horizontal_datum_name": "undefined",
     }
     cf_dict = crs.to_cf()
     assert cf_dict.pop("crs_wkt").startswith("GEOGCRS[")
@@ -253,6 +254,7 @@ def test_cf_from_latlon__named():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "geographic_crs_name": "WGS 84",
         "grid_mapping_name": "latitude_longitude",
     }
@@ -360,7 +362,7 @@ def test_cf_rotated_latlon():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "rotated_latitude_longitude",
         "grid_north_pole_latitude": 32.5,
         "grid_north_pole_longitude": 170.0,
@@ -532,7 +534,7 @@ def test_cf_lambert_conformal_conic_1sp():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_conformal_conic",
         "longitude_of_central_meridian": 265.0,
         "false_easting": 0.0,
@@ -596,7 +598,7 @@ def test_cf_lambert_conformal_conic_2sp(standard_parallel):
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_conformal_conic",
         "standard_parallel": (25.0, 30.0),
         "latitude_of_projection_origin": 25.0,
@@ -751,7 +753,7 @@ def test_geos_crs_sweep():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "geostationary",
         "sweep_angle_axis": "x",
         "perspective_point_height": 1.0,
@@ -799,7 +801,7 @@ def test_geos_crs_fixed_angle_axis():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "geostationary",
         "sweep_angle_axis": "x",
         "perspective_point_height": 1.0,
@@ -899,7 +901,7 @@ def test_mercator_b():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "mercator",
         "standard_parallel": 21.354,
         "longitude_of_projection_origin": 10.0,
@@ -1203,6 +1205,7 @@ def test_azimuthal_equidistant():
     assert cf_dict.pop("crs_wkt").startswith("PROJCRS[")
     assert cf_dict == expected_cf
     # test roundtrip
+    expected_cf["horizontal_datum_name"] = "World Geodetic System 1984 ensemble"
     _test_roundtrip(expected_cf, "PROJCRS[")
     # test coordinate system
     assert crs.cs_to_cf() == [
@@ -1230,7 +1233,7 @@ def test_lambert_azimuthal_equal_area():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_azimuthal_equal_area",
         "latitude_of_projection_origin": 1.0,
         "longitude_of_projection_origin": 2.0,
@@ -1270,7 +1273,7 @@ def test_lambert_cylindrical_equal_area():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_cylindrical_equal_area",
         "standard_parallel": 1.0,
         "longitude_of_central_meridian": 2.0,
@@ -1310,7 +1313,7 @@ def test_mercator_a():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "mercator",
         "standard_parallel": 0.0,
         "longitude_of_projection_origin": 2.0,
@@ -1351,7 +1354,7 @@ def test_orthographic():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "orthographic",
         "latitude_of_projection_origin": 1.0,
         "longitude_of_projection_origin": 2.0,
@@ -1391,7 +1394,7 @@ def test_polar_stereographic_a():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "polar_stereographic",
         "latitude_of_projection_origin": 90.0,
         "straight_vertical_longitude_from_pole": 1.0,
@@ -1432,7 +1435,7 @@ def test_polar_stereographic_b():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "polar_stereographic",
         "standard_parallel": 0.0,
         "straight_vertical_longitude_from_pole": 1.0,
@@ -1472,7 +1475,7 @@ def test_stereographic():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "stereographic",
         "latitude_of_projection_origin": 0.0,
         "longitude_of_projection_origin": 1.0,
@@ -1513,7 +1516,7 @@ def test_sinusoidal():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "sinusoidal",
         "longitude_of_projection_origin": 0.0,
         "false_easting": 1.0,
@@ -1552,7 +1555,7 @@ def test_vertical_perspective():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "vertical_perspective",
         "perspective_point_height": 50.0,
         "latitude_of_projection_origin": 0.0,
@@ -1889,7 +1892,7 @@ def test_3d_ellipsoidal_cs_depth():
             "name": "WGS 84 (geographic 3D)",
             "datum": {
                 "type": "GeodeticReferenceFrame",
-                "name": "World Geodetic System 1984",
+                "name": "World Geodetic System 1984 ensemble",
                 "ellipsoid": {
                     "name": "WGS 84",
                     "semi_major_axis": 6378137,
